"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateMdReport = exports.enrichReducedReportWithBaseline = exports.createReducedReport = void 0;
const lighthouse_1 = require("../../../hacky-things/lighthouse");
const md_table_1 = require("../../assert/utils/md-table");
function createReducedReport(flowResult) {
    const steps = flowResult.steps.map((step) => {
        var _a;
        let results;
        if ((_a = step === null || step === void 0 ? void 0 : step.lhr) === null || _a === void 0 ? void 0 : _a.categories) {
            const stepReport = lighthouse_1.Util.prepareReportResult(step.lhr);
            const { gatherMode } = stepReport;
            const categoriesEntries = Object.entries(stepReport.categories);
            results = categoriesEntries.reduce((res, [categoryName, category]) => {
                res[categoryName] = lighthouse_1.Util.shouldDisplayAsFraction(stepReport.gatherMode) ?
                    lighthouse_1.Util.calculateCategoryFraction(category) : (category).score;
                return res;
            }, {});
            return { name: step.name, gatherMode, results };
        }
        // @TODO inspect wrong step
        return undefined;
    }).filter(v => v !== undefined);
    return { name: flowResult.name, steps };
}
exports.createReducedReport = createReducedReport;
function enrichReducedReportWithBaseline(reducedReport, baselineReport) {
    const baselineReducedReport = createReducedReport(baselineReport);
    const baselineResults = Object.fromEntries(baselineReducedReport.steps.map((step) => [step.name, step.results]));
    const steps = reducedReport.steps.map((step) => (Object.assign(Object.assign({}, step), { 'baseline': baselineResults[step.name] })));
    return { name: reducedReport.name, steps };
}
exports.enrichReducedReportWithBaseline = enrichReducedReportWithBaseline;
function generateMdReport(flowResult) {
    const dateTime = new Date().toISOString().replace('T', ' ').split('.')[0].slice(0, -3);
    const mdTable = (0, md_table_1.userFlowReportToMdTable)(flowResult);
    return `# ${flowResult.name}\n\nDate/Time: ${dateTime}\n\n${mdTable}`;
}
exports.generateMdReport = generateMdReport;
//# sourceMappingURL=generate-reports.js.map